@@ -30,13 +30,6 @@ else:
             """when using jupyter-labhub, jupyterlab is default ui"""
             return "/lab"
 
-        def init_webapp(self, *args, **kwargs):
-            warnings.warn(
-                "SingleUserLabApp is deprecated, use SingleUserNotebookApp and set " + \
-                "c.Spawner.default_url = '/lab' in jupyterhub_config.py", DeprecationWarning
-            )
-            super().init_webapp(*args, **kwargs)
-
 
 def main(argv=None):
     return SingleUserLabApp.launch_instance(argv)
